// @ts-nocheck
import { combineReducers, configureStore } from '@reduxjs/toolkit';
import { TypedUseSelectorHook, useDispatch, useSelector } from 'react-redux';

import authReducer from '@procyon/auth/slice';

import { emptyApi } from './emptyApi';

export const makeStore = () =>
	configureStore({
		reducer: {
			procyon: combineReducers({
				auth: authReducer,
			}),
			[emptyApi.reducerPath]: emptyApi.reducer,
		},
		middleware: (gDM) => gDM().prepend(emptyApi.middleware),
		devTools: process.env.NODE_ENV === 'development',
	});

export type ReduxStore = ReturnType<typeof makeStore>;

export type RootState = ReturnType<ReduxStore['getState']>;
export type AppDispatch = ReduxStore['dispatch'];

export const useAppDispatch: () => AppDispatch = useDispatch;
export const useAppSelector: TypedUseSelectorHook<RootState> = useSelector;
